# Guess File Type
Detect the file type by doing various checks. Returns the mime type.



## How it Works

* First it tries to use the `mimetype` command. See Requirements > Optional.
* If `mimetype` is not available, it uses the file signature (magic numbers).
* If the type could not be determined, it falls back to using the file extension.
* It returns the mime type of the file on success, and a string 'unknown' on failure.

### Changing the Behavior

You can avoid the default behavior by using the individual functions. See Usage.

## Requirements

* Node >= 8.0.0

### Optional

To improve mime detection, install the `mimetype` command:

    sudo apt install libfile-mimeinfo-perl

Its results are much more accurate than `file`.

## Installation

    npm install guess-file-type


## Usage

    const fileGuesser = require('guess-file-type');

### Auto guess the type

#### Async:
    try {
        let type = await fileGuesser.guess('./test/files/gif.gif');
        console.log(type); // 'image/gif' or 'unknown' on fail
    } catch (err) {
        
    }

#### Promise:

    fileGuesser.guess('./test/files/gif.gif').then( (type) => {
        console.log(type); // 'image/gif' or 'unknown' on fail
    }).catch((err)=>{

    });


### Manual Checking

You can call the individual functions separately and compose them if neccessary.

#### Guess using the file signature only

Async:

    try {
        let type = await fileGuesser.guessByFileSignature('./test/files/png.png');
        console.log(type);  // 'image/png' or 'unknown' on fail
    } catch(err){}

Promise: 

    fileGuesser.guessByFileSignature('./test/files/png.png').then((type)=>{
        console.log(type);  // 'image/png' or 'unknown' on fail
    }).catch((err)=>{});

#### Guess using the file extension only

Async:

    try {
        let type = await fileGuesser.guessByExtension('./test/files/png.png');
        console.log(type);  // 'image/png' or 'unknown' on fail
    } catch(err){}

Promise:

    fileGuesser.guessByExtension('./test/files/png.png').then((type)=>{
        console.log(type);  // 'image/png' or 'unknown' on fail
    }).catch((err)=>{});


#### Get file extension from mime type

    let ext = guessFileType.getExtensionFromMime('image/png'); // png

## References

* https://www.iana.org/assignments/media-types/media-types.xhtml
* http://svn.apache.org/viewvc/httpd/httpd/trunk/docs/conf/mime.types?view=markup
* https://www.garykessler.net/library/file_sigs.html
* https://en.wikipedia.org/wiki/List_of_file_signatures

## Supported Types

1. 123
1. 3dml
1. 3ds
1. 3g2
1. 3gp
1. 7z
1. aab
1. aac
1. aam
1. aas
1. abw
1. ac
1. acc
1. ace
1. acu
1. acutc
1. adp
1. aep
1. afm
1. afp
1. ahead
1. ai
1. aif
1. aifc
1. aiff
1. air
1. ait
1. ami
1. apk
1. appcache
1. application
1. apr
1. arc
1. asc
1. asf
1. asm
1. aso
1. asx
1. atc
1. atom
1. atomcat
1. atomsvc
1. atx
1. au
1. avi
1. aw
1. azf
1. azs
1. azw
1. bat
1. bcpio
1. bdf
1. bdm
1. bed
1. bh2
1. bin
1. blb
1. blorb
1. bmi
1. bmp
1. book
1. box
1. boz
1. bpk
1. btif
1. bz
1. bz2
1. c
1. c11amc
1. c11amz
1. c4d
1. c4f
1. c4g
1. c4p
1. c4u
1. cab
1. caf
1. cap
1. car
1. cat
1. cb7
1. cba
1. cbr
1. cbt
1. cbz
1. cc
1. cct
1. ccxml
1. cdbcmsg
1. cdf
1. cdkey
1. cdmia
1. cdmic
1. cdmid
1. cdmio
1. cdmiq
1. cdx
1. cdxml
1. cdy
1. cer
1. cfs
1. cgm
1. chat
1. chm
1. chrt
1. cif
1. cii
1. cil
1. cla
1. class
1. clkk
1. clkp
1. clkt
1. clkw
1. clkx
1. clp
1. cmc
1. cmdf
1. cml
1. cmp
1. cmx
1. cod
1. com
1. conf
1. cpio
1. cpp
1. cpt
1. crd
1. crl
1. crt
1. cryptonote
1. csh
1. csml
1. csp
1. css
1. cst
1. csv
1. cu
1. curl
1. cww
1. cxt
1. cxx
1. dae
1. daf
1. dart
1. dataless
1. davmount
1. dbk
1. dcr
1. dcurl
1. dd2
1. ddd
1. deb
1. def
1. deploy
1. der
1. dfac
1. dgc
1. dic
1. dir
1. dis
1. dist
1. distz
1. djv
1. djvu
1. dll
1. dmg
1. dmp
1. dms
1. dna
1. doc
1. docm
1. docx
1. dot
1. dotm
1. dotx
1. dp
1. dpg
1. dra
1. dsc
1. dssc
1. dtb
1. dtd
1. dts
1. dtshd
1. dump
1. dvb
1. dvi
1. dwf
1. dwg
1. dxf
1. dxp
1. dxr
1. ecelp4800
1. ecelp7470
1. ecelp9600
1. ecma
1. edm
1. edx
1. efif
1. ei6
1. elc
1. emf
1. eml
1. emma
1. emz
1. eol
1. eot
1. eps
1. epub
1. es3
1. esa
1. esf
1. et3
1. etx
1. eva
1. evy
1. exe
1. exi
1. ext
1. ez
1. ez2
1. ez3
1. f
1. f4v
1. f77
1. f90
1. fbs
1. fcdt
1. fcs
1. fdf
1. fe_launch
1. fg5
1. fgd
1. fh
1. fh4
1. fh5
1. fh7
1. fhc
1. fig
1. flac
1. fli
1. flo
1. flv
1. flw
1. flx
1. fly
1. fm
1. fnc
1. for
1. fpx
1. frame
1. fsc
1. fst
1. ftc
1. fti
1. fvt
1. fxp
1. fxpl
1. fzs
1. g2w
1. g3
1. g3w
1. gac
1. gam
1. gbr
1. gca
1. gdl
1. geo
1. gex
1. ggb
1. ggt
1. ghf
1. gif
1. gim
1. gml
1. gmx
1. gnumeric
1. gph
1. gpx
1. gqf
1. gqs
1. gram
1. gramps
1. gre
1. grv
1. grxml
1. gsf
1. gtar
1. gtm
1. gtw
1. gv
1. gxf
1. gxt
1. h
1. h261
1. h263
1. h264
1. hal
1. hbci
1. hdf
1. hh
1. hlp
1. hpgl
1. hpid
1. hps
1. hqx
1. htke
1. htm
1. html
1. hvd
1. hvp
1. hvs
1. i2g
1. icc
1. ice
1. icm
1. ico
1. ics
1. ief
1. ifb
1. ifm
1. iges
1. igl
1. igm
1. igs
1. igx
1. iif
1. imp
1. ims
1. in
1. ink
1. inkml
1. install
1. iota
1. ipfix
1. ipk
1. irm
1. irp
1. iso
1. itp
1. ivp
1. ivu
1. jad
1. jam
1. jar
1. java
1. jisp
1. jlt
1. jnlp
1. joda
1. jpe
1. jpeg
1. jpg
1. jpgm
1. jpgv
1. jpm
1. js
1. json
1. jsonml
1. kar
1. karbon
1. kfo
1. kia
1. kml
1. kmz
1. kne
1. knp
1. kon
1. kpr
1. kpt
1. kpxx
1. ksp
1. ktr
1. ktx
1. ktz
1. kwd
1. kwt
1. lasxml
1. latex
1. lbd
1. lbe
1. les
1. lha
1. link66
1. list
1. list3820
1. listafp
1. lnk
1. log
1. lostxml
1. lrf
1. lrm
1. ltf
1. lvp
1. lwp
1. lzh
1. m13
1. m14
1. m1v
1. m21
1. m2a
1. m2v
1. m3a
1. m3u
1. m3u8
1. m4a
1. m4u
1. m4v
1. ma
1. mads
1. mag
1. maker
1. man
1. mar
1. mathml
1. mb
1. mbk
1. mbox
1. mc1
1. mcd
1. mcurl
1. mdb
1. mdi
1. me
1. mesh
1. meta4
1. metalink
1. mets
1. mfm
1. mft
1. mgp
1. mgz
1. mid
1. midi
1. mie
1. mif
1. mime
1. mj2
1. mjp2
1. mk3d
1. mka
1. mks
1. mkv
1. mlp
1. mmd
1. mmf
1. mmr
1. mng
1. mny
1. mobi
1. mods
1. mov
1. movie
1. mp2
1. mp21
1. mp2a
1. mp3
1. mp4
1. mp4a
1. mp4s
1. mp4v
1. mpc
1. mpe
1. mpeg
1. mpg
1. mpg4
1. mpga
1. mpkg
1. mpm
1. mpn
1. mpp
1. mpt
1. mpy
1. mqy
1. mrc
1. mrcx
1. ms
1. mscml
1. mseed
1. mseq
1. msf
1. msh
1. msi
1. msl
1. msty
1. mts
1. mus
1. musicxml
1. mvb
1. mwf
1. mxf
1. mxl
1. mxml
1. mxs
1. mxu
1. n-gage
1. n3
1. nb
1. nbp
1. nc
1. ncx
1. nfo
1. ngdat
1. nitf
1. nlu
1. nml
1. nnd
1. nns
1. nnw
1. npx
1. nsc
1. nsf
1. ntf
1. nzb
1. oa2
1. oa3
1. oas
1. obd
1. obj
1. oda
1. odb
1. odc
1. odf
1. odft
1. odg
1. odi
1. odm
1. odp
1. ods
1. odt
1. oga
1. ogg
1. ogv
1. ogx
1. omdoc
1. onepkg
1. onetmp
1. onetoc
1. onetoc2
1. opf
1. opml
1. oprc
1. org
1. osf
1. osfpvg
1. otc
1. otf
1. otg
1. oth
1. oti
1. otp
1. ots
1. ott
1. oxps
1. oxt
1. p
1. p10
1. p12
1. p7b
1. p7c
1. p7m
1. p7r
1. p7s
1. p8
1. pas
1. paw
1. pbd
1. pbm
1. pcap
1. pcf
1. pcl
1. pclxl
1. pct
1. pcurl
1. pcx
1. pdb
1. pdf
1. pfa
1. pfb
1. pfm
1. pfr
1. pfx
1. pgm
1. pgn
1. pgp
1. pic
1. pkg
1. pki
1. pkipath
1. plb
1. plc
1. plf
1. pls
1. pml
1. png
1. pnm
1. portpkg
1. pot
1. potm
1. potx
1. ppam
1. ppd
1. ppm
1. pps
1. ppsm
1. ppsx
1. ppt
1. pptm
1. pptx
1. pqa
1. prc
1. pre
1. prf
1. ps
1. psb
1. psd
1. psf
1. pskcxml
1. ptid
1. pub
1. pvb
1. pwn
1. pya
1. pyv
1. qam
1. qbo
1. qfx
1. qps
1. qt
1. qwd
1. qwt
1. qxb
1. qxd
1. qxl
1. qxt
1. ra
1. ram
1. rar
1. ras
1. rcprofile
1. rdf
1. rdz
1. rep
1. res
1. rgb
1. rif
1. rip
1. ris
1. rl
1. rlc
1. rld
1. rm
1. rmi
1. rmp
1. rms
1. rmvb
1. rnc
1. roa
1. roff
1. rp9
1. rpss
1. rpst
1. rq
1. rs
1. rsd
1. rss
1. rtf
1. rtx
1. s
1. s3m
1. saf
1. sbml
1. sc
1. scd
1. scm
1. scq
1. scs
1. scurl
1. sda
1. sdc
1. sdd
1. sdkd
1. sdkm
1. sdp
1. sdw
1. see
1. seed
1. sema
1. semd
1. semf
1. ser
1. setpay
1. setreg
1. sfd-hdstx
1. sfs
1. sfv
1. sgi
1. sgl
1. sgm
1. sgml
1. sh
1. shar
1. shf
1. sid
1. sig
1. sil
1. silo
1. sis
1. sisx
1. sit
1. sitx
1. skd
1. skm
1. skp
1. skt
1. sldm
1. sldx
1. slt
1. sm
1. smf
1. smi
1. smil
1. smv
1. smzip
1. snd
1. snf
1. so
1. spc
1. spf
1. spl
1. spot
1. spp
1. spq
1. spx
1. sql
1. src
1. srt
1. sru
1. srx
1. ssdl
1. sse
1. ssf
1. ssml
1. st
1. stc
1. std
1. stf
1. sti
1. stk
1. stl
1. str
1. stw
1. sub
1. sub
1. sus
1. susp
1. sv4cpio
1. sv4crc
1. svc
1. svd
1. svg
1. svgz
1. swa
1. swf
1. swi
1. sxc
1. sxd
1. sxg
1. sxi
1. sxm
1. sxw
1. t
1. t3
1. taglet
1. tao
1. tar
1. tcap
1. tcl
1. teacher
1. tei
1. teicorpus
1. tex
1. texi
1. texinfo
1. text
1. tfi
1. tfm
1. tga
1. thmx
1. tif
1. tiff
1. tmo
1. torrent
1. tpl
1. tpt
1. tr
1. tra
1. trm
1. tsd
1. tsv
1. ttc
1. ttf
1. ttl
1. twd
1. twds
1. txd
1. txf
1. txt
1. u32
1. udeb
1. ufd
1. ufdl
1. ulx
1. umj
1. unityweb
1. uoml
1. uri
1. uris
1. urls
1. ustar
1. utz
1. uu
1. uva
1. uvd
1. uvf
1. uvg
1. uvh
1. uvi
1. uvm
1. uvp
1. uvs
1. uvt
1. uvu
1. uvv
1. uvva
1. uvvd
1. uvvf
1. uvvg
1. uvvh
1. uvvi
1. uvvm
1. uvvp
1. uvvs
1. uvvt
1. uvvu
1. uvvv
1. uvvx
1. uvvz
1. uvx
1. uvz
1. vcard
1. vcd
1. vcf
1. vcg
1. vcs
1. vcx
1. vis
1. viv
1. vob
1. vor
1. vox
1. vrml
1. vsd
1. vsf
1. vss
1. vst
1. vsw
1. vtu
1. vxml
1. w3d
1. wad
1. wav
1. wax
1. wbmp
1. wbs
1. wbxml
1. wcm
1. wdb
1. wdp
1. weba
1. webm
1. webp
1. wg
1. wgt
1. wks
1. wm
1. wma
1. wmd
1. wmf
1. wml
1. wmlc
1. wmls
1. wmlsc
1. wmv
1. wmx
1. wmz
1. wmz
1. woff
1. woff2
1. wpd
1. wpl
1. wps
1. wqd
1. wri
1. wrl
1. wsdl
1. wspolicy
1. wtb
1. wvx
1. x32
1. x3d
1. x3db
1. x3dbz
1. x3dv
1. x3dvz
1. x3dz
1. xaml
1. xap
1. xar
1. xbap
1. xbd
1. xbm
1. xdf
1. xdm
1. xdp
1. xdssc
1. xdw
1. xenc
1. xer
1. xfdf
1. xfdl
1. xht
1. xhtml
1. xhvml
1. xif
1. xla
1. xlam
1. xlc
1. xlf
1. xlm
1. xls
1. xlsb
1. xlsm
1. xlsx
1. xlt
1. xltm
1. xltx
1. xlw
1. xm
1. xml
1. xo
1. xop
1. xpi
1. xpl
1. xpm
1. xpr
1. xps
1. xpw
1. xpx
1. xsl
1. xslt
1. xsm
1. xspf
1. xul
1. xvm
1. xvml
1. xwd
1. xyz
1. xz
1. yang
1. yin
1. z1
1. z2
1. z3
1. z4
1. z5
1. z6
1. z7
1. z8
1. zaz
1. zip
1. zir
1. zirz
1. zmm



When using `mimetype`, supported types will depend on your mime database: cat /usr/share/mime/types. 
See: [http://manpages.ubuntu.com/manpages/xenial/en/man1/mimetype.1p.html](http://manpages.ubuntu.com/manpages/xenial/en/man1/mimetype.1p.html)